CAP_WIDTH = .4;
CAP_DIAM = 6.5;
CAP_COLOR = "white";

BODY_LENGTH = 16.8 - CAP_WIDTH;
BODY_DIAM = 7;
BODY_COLOR = "lightgrey";

BODY_SHAFT_EXT_LENGTH = 3;
BODY_SHAFT_EXT_DIAM = 3;

BODY_MASS_DIST = 1.2;

MASS_LENGTH = 5.5;
MASS_DIAM = 3.3 * 2;
MASS_SHAFT_DIAM = 2;
MASS_BORE_LENGTH = 3;
MASS_BORE_DIAM = 3.5;
MASS_COLOR = "teal";

SHAFT_DIAM = 1;
SHAFT_OFFSET = .5;
SHAFT_LENGTH = BODY_LENGTH + BODY_MASS_DIST + MASS_LENGTH + SHAFT_OFFSET;
SHAFT_COLOR = "dimgrey";

module draw_cylinder(l, d, c) {
    rotate([90,0,0]) color (c) cylinder(h=l, d=d);
}

module draw_mass(l, d, sd, bl, bd, o, c) {
    rotate([90,0,0]) {
        difference() { // Bore hole in mass
            union() {
                // Draw mass shaft inner cylinder
                color(c) cylinder(h=l, d=sd);
                difference() { // Make half-cylinder
                    color(c) cylinder(h=l, d=d);
                    translate([-l,0,-l/2])
                    color(c) cube([l*2,l,l*2]);
                }
            }
            translate([0,0,-o])
            color(c) cylinder(h=bl+o, d=bd);
        }
    }
}

// Draw body
translate([0, (BODY_LENGTH + BODY_MASS_DIST), 0])
draw_cylinder(BODY_LENGTH, BODY_DIAM, BODY_COLOR);
// Draw body shaft extension
translate([0, BODY_MASS_DIST, 0])
draw_cylinder(BODY_SHAFT_EXT_LENGTH, BODY_SHAFT_EXT_DIAM, BODY_COLOR);
// Draw body plastic cap
translate([0, (BODY_LENGTH + CAP_WIDTH + BODY_MASS_DIST), 0])
draw_cylinder(CAP_WIDTH, CAP_DIAM, CAP_COLOR);

// Draw shaft
translate([0, (BODY_LENGTH + BODY_MASS_DIST + SHAFT_OFFSET/2), 0])
draw_cylinder(SHAFT_LENGTH, SHAFT_DIAM, SHAFT_COLOR);

// Draw rotating mass
draw_mass(MASS_LENGTH, MASS_DIAM, MASS_SHAFT_DIAM, MASS_BORE_LENGTH, MASS_BORE_DIAM, BODY_MASS_DIST/2, MASS_COLOR);
