LENGTH = 2;
WIDTH = 1.2;
HEIGHT = .6;

CASE_X = LENGTH;
CASE_Y = WIDTH;
CASE_Z = HEIGHT *2/3;
CASE_COLOR = "dimgray";

LID_X = CASE_X - .3;
LID_Y = CASE_Y - .3;
LID_Z = HEIGHT - CASE_Z - .05;
LID_COLOR = "gold";

LID_TOP_X = LID_X * 9/10;
LID_TOP_Y = LID_Y * 9/10;
LID_TOP_Z = HEIGHT - LID_Z - CASE_Z;
LID_TOP_COLOR = "lightgray";

PAD_X = .4;
PAD_Y = 1.1;
PAD_Z = .02;
PAD_STEP_X = 1 + .5;
PAD_STEP_Y = .45 + .5;
PAD_NUM = 2;
PAD_COLOR = "gold";

PAD_CYL_DIAM = .25;

module draw_case(x,y,z,c) {
    color(c) cube([x,y,z], true);
}

module draw_pad(x, y, z, c) {
    color (c) cube([x, y, z], true);
}

module draw_marker(s, d, c) {
    color (c) linear_extrude(d) circle(s/2);
}

module draw_pad_array(x, y, length, width, height, step_x, step_y, color) {
    for(i = [0:x-1]) {
        for(j = [0:y-1]) {
            translate ([i*step_x,j*step_y,0]) draw_pad(length, width, height, color);
        }
    }
}

translate([0,0,CASE_Z/2+PAD_Z]) {// Set model flat on Z axis
difference() {
    union() {
        // Draw the bottom case
        draw_case(CASE_X, CASE_Y, CASE_Z, CASE_COLOR);
        
        // Draw the lid bottom 
        translate([0,0,+(HEIGHT-LID_TOP_Z)/2])
        draw_case(LID_X, LID_Y, LID_Z, LID_COLOR);   

        // Draw the lid top 
        translate([0,0,+(HEIGHT+LID_Z)/2])
        draw_case(LID_TOP_X, LID_TOP_Y, LID_TOP_Z, LID_TOP_COLOR);  

        // Draw the pads
        translate([-PAD_STEP_X/2, -(PAD_NUM/2-1)*PAD_STEP_Y/2, -(CASE_Z+PAD_Z)/2])
        draw_pad_array(2, PAD_NUM/2, PAD_X, PAD_Y, PAD_Z, PAD_STEP_X, PAD_STEP_Y, PAD_COLOR);
    }
    // Draw castellated pad 1/4 holes
    union() {
        color(PAD_COLOR) translate([LENGTH/2, WIDTH/2, 0]) cylinder(h=HEIGHT, d=PAD_CYL_DIAM, , center = true);
        color(PAD_COLOR) translate([-LENGTH/2, WIDTH/2, 0]) cylinder(h=HEIGHT, d=PAD_CYL_DIAM, , center = true);
        color(PAD_COLOR) translate([LENGTH/2, -WIDTH/2, 0]) cylinder(h=HEIGHT, d=PAD_CYL_DIAM, , center = true);
        color(PAD_COLOR) translate([-LENGTH/2, -WIDTH/2, 0]) cylinder(h=HEIGHT, d=PAD_CYL_DIAM, , center = true);
    }
        
}
}